version

package
v3.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 17, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	PackageSignatureSchemaVersion = "package-signature-v1"
	TargetClassifierVersion       = "target-classifier-v2"
)
const StrictSemVerPattern = `` /* 214-byte string literal not displayed */

Variables

var (
	ErrInvalidSemVer = errors.New("invalid semantic version")
)

Functions

func CurrentPlatformVersion

func CurrentPlatformVersion() string

Types

type SemVer

type SemVer struct {
	// contains filtered or unexported fields
}

SemVer is an immutable semantic version in the public, prefix-free form. Its zero value is invalid and cannot be encoded.

func ParseSemVer

func ParseSemVer(value string) (SemVer, error)

func (SemVer) Compare

func (v SemVer) Compare(other SemVer) int

func (SemVer) MarshalJSON

func (v SemVer) MarshalJSON() ([]byte, error)

func (SemVer) MarshalText

func (v SemVer) MarshalText() ([]byte, error)

func (SemVer) String

func (v SemVer) String() string

func (*SemVer) UnmarshalJSON

func (v *SemVer) UnmarshalJSON(raw []byte) error

func (*SemVer) UnmarshalText

func (v *SemVer) UnmarshalText(text []byte) error

Jump to