Documentation
¶
Index ¶
Constants ¶
const ( PackageSignatureSchemaVersion = "package-signature-v1" TargetClassifierVersion = "target-classifier-v2" )
const StrictSemVerPattern = `` /* 214-byte string literal not displayed */
Variables ¶
var (
ErrInvalidSemVer = errors.New("invalid semantic version")
)
Functions ¶
func CurrentPlatformVersion ¶
func CurrentPlatformVersion() string
Types ¶
type SemVer ¶
type SemVer struct {
// contains filtered or unexported fields
}
SemVer is an immutable semantic version in the public, prefix-free form. Its zero value is invalid and cannot be encoded.
func ParseSemVer ¶
func (SemVer) MarshalJSON ¶
func (SemVer) MarshalText ¶
func (*SemVer) UnmarshalJSON ¶
func (*SemVer) UnmarshalText ¶
Click to show internal directories.
Click to hide internal directories.